#
# spec file for package kf6-krunner
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.6.0

%define rname krunner
# Full KF6 version (e.g. 6.3.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-krunner
Version:        6.3.0
Release:        1.1
Summary:        KDE Framework for providing different actions given a string query
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ItemModels) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ThreadWeaver) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}

%description
KDE Framework for providing different actions given a string query.

%package -n libKF6Runner6
Summary:        KDE Framework for providing different actions given a string query
Requires:       kf6-krunner >= %{version}

%description -n libKF6Runner6
KDE Framework for providing different actions given a string query.

%package devel
Summary:        KDE Framework for providing different actions given a string query
Requires:       libKF6Runner6 = %{version}
Requires:       cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
Requires:       cmake(Qt6Core) >= %{qt6_version}
Requires:       cmake(Qt6Gui) >= %{qt6_version}

%description devel
Files needed for developing custom runners or frontends.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%ldconfig_scriptlets -n libKF6Runner6

%files
%{_kf6_debugdir}/krunner.categories
%{_kf6_debugdir}/krunner.renamecategories

%files -n libKF6Runner6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6Runner.so.*

%files devel
%doc %{_kf6_qchdir}/KF6Runner.*
%{_kf6_cmakedir}/KF6Runner/
%{_kf6_dbusinterfacesdir}/kf6_org.kde.krunner1.xml
%{_kf6_includedir}/KRunner/
%{_kf6_libdir}/libKF6Runner.so
%{_kf6_sharedir}/kdevappwizard/

%changelog
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Fix X-KDE-ConfigModule not working for DBus runners
  * Fix same query not yielding results in new match session
  * Remove explicit maintainer from metainfo
  * templates/runner6python: Only depend on shebang line for executing
  * Rename entrypoint file to always be main.py
  * Document krunner-plugininstallerrc file
  * Document how AbstractRunner::config is resolved
  * runnercontext: Fix saving the launch counts
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * runnercontext: Fix saving the launch counts
  * update version for new release
  * update version for new release
  * Action: Make bool operator explicit
  * Fix matchInternalFinished not being emitted in case of dbus errors
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Add doxygen comment to ResultsModel class
  * Give favorites a relative boost rather than absolute sorting position
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * Fix clang-tidy issues
  * Runner C++ template: unbreak build due to KDEFrameworkCompilerSettings use
  * Runner C++ template:  bump min Qt/KF deps to match initial KF6 release
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-krunner
